@@ -1,19 +1,27 @@
-from django.template import Context
 from django.template.loader import get_template
 
 
 class FormControlMixin(object):
     css_class = 'form-control'
 
-    def render(self, name, value, attrs=None):
-        attrs = attrs or dict()
+    def render(self, name, value, attrs=None, renderer=None):
+        return super(FormControlMixin, self).render(name, value, self._get_attrs(attrs), renderer)
+
+    def _get_attrs(self, attrs_param):
+        def get_param():
+            if attrs_param:
+                return dict(attrs_param)
+            else:
+                return dict()
+
+        attrs = get_param()
 
         class_string = self._get_class_string(attrs)
 
         if class_string:
             attrs['class'] = class_string
 
-        return super(FormControlMixin, self).render(name, value, attrs)
+        return attrs
 
     def _get_class_string(self, attrs):
         classes = []
@@ -39,10 +47,7 @@ class TemplatedWidget(object):
 
     def render(self, name, value, attrs=None, label=None):
         template = self.get_template()
-
-        context = Context(
-            self.get_context(name, value, attrs, label)
-        )
+        context = self.get_context(name, value, attrs, label)
 
         return template.render(context)
 
@@ -58,4 +63,4 @@ class TemplatedWidget(object):
         if not hasattr(self, '_template'):
             self._template = get_template(self.template_name)
 
-        return self._template
\ No newline at end of file
+        return self._template
